==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/fa.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "اشتراک سرور به سرور در این سرور فعال نیست .",
    "The mountpoint name contains invalid characters." : "نام نقطه ی اتصال حاوی کاراکتر های غیرمجاز است.",
    "Not allowed to create a federated share with the same user server" : "ایجاد اشتراک گذاری گروهی با کاربر سرور یکسان مجاز نمی باشد.",
    "Invalid or untrusted SSL certificate" : "گواهینامه SSL غیر قابل اعتماد یا غیر معتبر است.",
    "Could not authenticate to remote share, password might be wrong" : "احرازهویت برای اشتراک‌گذاری راه‌دور انجام نشد، احتمالا رمزعبور نادرست است",
    "Storage not valid" : "فضای ذخیره‌سازی معتبر نیست",
    "Couldn't add remote share" : "امکان افزودن اشتراک گذاری از راه دور وجود ندارد",
    "Shared with you" : "موارد به اشتراک گذاشته شده با شما",
    "Shared with others" : "موارد به اشتراک گذاشته شده با دیگران",
    "Shared by link" : "اشتراک گذاشته شده از طریق پیوند",
    "Uploading..." : "درحال بارگذاری...",
    "Nothing shared with you yet" : "هیچ موردی با شما به اشتراک گذاشته نشده است",
    "Files and folders others share with you will show up here" : "فایل ها و پوشه ها که دیگران با شما به اشتراک گذاشته اند در اینجا نمایش داده میشود.",
    "Nothing shared yet" : "هیچ موردی تاکنون به اشتراک گذاشته نشده است",
    "Files and folders you share will show up here" : "فایل ها و پوشه هایی که به اشتراک گذاشته اید در اینجا نمایش داده می شود.",
    "No shared links" : "هیچ لینک اشتراک‌گذاری وجود ندارد",
    "Files and folders you share by link will show up here" : "فایل‌ها و پوشه‌های اشتراک‌گذاشته توسط شما همراه با لینک در اینجا نمایش داده خواهد شد",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "آیا مایل به افزودن اشتراک از راه دور {name} از {owner}@{remote} هستید.",
    "Remote share" : "اشتراک از راه دور",
    "Remote share password" : "رمز عبور اشتراک از راه دور",
    "Cancel" : "منصرف شدن",
    "Add remote share" : "افزودن اشتراک از راه دور",
    "You can upload into this folder" : "می‌توانید در این پوشه آپلود کنید",
    "No ownCloud installation (7 or higher) found at {remote}" : "هیچ نصبinstallation (7 or higher) در  {remote} پیدا نشد.",
    "Invalid ownCloud url" : "آدرس نمونه ownCloud  غیر معتبر است",
    "Share" : "اشتراک گذاری",
    "No expiration date set" : "تاریخ انقضا تعیین نشده است.",
    "Shared by" : "اشتراک گذاشته شده به وسیله",
    "Sharing" : "اشتراک گذاری",
    "Share API is disabled" : "API اشتراک گذاری غیر فعال است.",
    "Wrong share ID, share doesn't exist" : "شناسه اشتراک گذاری اشتباه است، اشتراک گذاری وجود ندارد.",
    "Could not delete share" : "امکان حذف اشتراک گذاری وجود ندارد.",
    "Please specify a file or folder path" : "لطفا مسیر فایل یا پوشه را مشخص کنید.",
    "Wrong path, file/folder doesn't exist" : "مسیر اشتباه، فایل یا پوشه وجود ندارد.",
    "Please specify a valid user" : "لطفا یک کاربر معتبر را تعیین کنید.",
    "Group sharing is disabled by the administrator" : "اشتراک گذاری گروهی توسط مدیر غیر فعال شده است.",
    "Please specify a valid group" : "لطفا یک گروه معتبر را معرفی کنید.",
    "Public link sharing is disabled by the administrator" : "اشتراک گذاری لینک عمومی توسط مدیر غیر فعال شده است.",
    "Public upload disabled by the administrator" : "بارگذاری عمومی توسط مدیر غیر فعال شده است.",
    "Public upload is only possible for publicly shared folders" : "بارگذاری عمومی فقط برای پوشه های اشتراک گذاری عمومی امکان پذیر است.",
    "Invalid date, date format must be YYYY-MM-DD" : "تاریخ نامعتبر، قالب تاریخ باید YYYY-MM-DD باشد.",
    "Sharing %s failed because the back end does not allow shares from type %s" : "اشتراک گذاری %s ناموفق بود، زیرا اشتراک گذاری از نوع %s مجاز نیست.",
    "Unknown share type" : "نوع اشتراک گذاری نامعلوم.",
    "Not a directory" : "یک دایرکتوری نمی باشد.",
    "Could not lock path" : "امکان قفل کردن مسیر نمی باشد.",
    "Can't change permissions for public share links" : "امکان تغییر مجوز ها برای لینک های اشتراک گذاری عمومی فراهم نیست.",
    "Wrong or no update parameter given" : "پارامتر های بروز رسانی اشتباه اند یا تعیین نشده اند",
    "Cannot increase permissions" : "امکان افزایش مجوز ها نمی باشد",
    "A file or folder has been <strong>shared</strong>" : "فایل یا پوشه ای به <strong>اشتراک</strong> گذاشته شد",
    "A file or folder was shared from <strong>another server</strong>" : "یک فایل یا پوشه از <strong> سروری دیگر </strong>  به اشتراک گذاشته شد",
    "A public shared file or folder was <strong>downloaded</strong>" : "یک فایل یا پوشه به اشتراک گذاشته شده <strong> دانلود شده است</strong>",
    "You received a new remote share %2$s from %1$s" : "شما یک اشتراک گذاری ریموت %1$s از  %2$s دریافت کرده اید",
    "You received a new remote share from %s" : "شما یک اشتراک گذاری جدید دریافت کرده اید از%s",
    "%1$s accepted remote share %2$s" : "%1$s پذیرفته یک اشتراک گذاری ریموت را%2$s",
    "%1$s declined remote share %2$s" : "%1$s اشتراک گذاری ریموت %2$s را معتبر نمیداند",
    "%1$s unshared %2$s from you" : "%1$s از اشتراک گذاری %2$s با شما خارج شد",
    "Public shared folder %1$s was downloaded" : "پوشه ی اشتراک گذاری عمومی  %1$s دانلود شده است",
    "Public shared file %1$s was downloaded" : "فایل اشتراک گذاری عمومی  %1$s دانلود شده است",
    "You shared %1$s with %2$s" : "شما %1$s را با %2$s به اشتراک گذاشتید",
    "%2$s shared %1$s with %3$s" : "%2$s به اشتراک گذاشته شد %1$s با %3$s",
    "You removed the share of %2$s for %1$s" : "شما اشتراک گذاری %2$s برای %1$s را حذف کرده اید",
    "%2$s removed the share of %3$s for %1$s" : "%2$s اشتراک گذاری %3$s برای %1$s حذف شده است",
    "You shared %1$s with group %2$s" : "شما %1$s را با گروه %2$s به اشتراک گذاشتید",
    "%2$s shared %1$s with group %3$s" : "%2$s به اشتراک گذاشته شد  %1$s با گروه %3$s",
    "You removed the share of group %2$s for %1$s" : "شما اشتراک گذاری گروه %2$s برای %1$s را حذف کرده اید",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s اشتراک گذاری گروه %3$s برای %1$s حذف شده است",
    "%2$s shared %1$s via link" : "%2$s به اشتراک گذاشته شده %1$s از طریق لینک",
    "You shared %1$s via link" : "شما %1$s را توسط پیوند به اشتراک گذاشتید",
    "You removed the public link for %1$s" : "شما لینک عمومی برای %1$s را حذف کرده اید",
    "%2$s removed the public link for %1$s" : "%2$s لینک عمومی برای %1$s حذف شده است",
    "Your public link for %1$s expired" : "لینک عمومی شما برای %1$s منقضی شده است",
    "The public link of %2$s for %1$s expired" : "لینک عمومی %2$s برای %1$s منقضی شده است",
    "%2$s shared %1$s with you" : "%2$s مورد %1$s را با شما به اشتراک گذاشت",
    "%2$s removed the share for %1$s" : "%2$s اشتراک گذاری برای%1$s را حذف کرده است ",
    "Downloaded via public link" : "دانلود از طریق لینک عمومی",
    "Shared with %2$s" : "اشتراک گذاشته شده با %2$s",
    "Shared with %3$s by %2$s" : "اشتراک گذاشته شده با %3$s توسط%2$s ",
    "Removed share for %2$s" : "اشتراک گذاری %2$s حذف شده است",
    "%2$s removed share for %3$s" : "%2$sاشتراک گذاری برای %3$s را حذف کرده است ",
    "Shared with group %2$s" : "اشتراک گذاشته شده با گروه %2$s",
    "Shared with group %3$s by %2$s" : "به اشتراک گذاشته شده با گروه %3$s توسط %2$s",
    "Removed share of group %2$s" : "حذف شده از اشتراک گذاری گروه %2$s",
    "%2$s removed share of group %3$s" : "%2$s از گروه %3$s حذف شده است",
    "Shared via link by %2$s" : "به اشتراک گذاشته شده با لینک توسط %2$s",
    "Shared via public link" : "به اشتراک گذاشته شده از طریق لینک عمومی",
    "Removed public link" : "لینک عمومی حذف شده است",
    "%2$s removed public link" : "%2$s لینک  عمومی را حذف کرده است",
    "Public link expired" : "لینک عمومی منقضی شده است",
    "Public link of %2$s expired" : "لینک عمومی %2$s منقضی شده است",
    "Shared by %2$s" : "به اشتراک گذاشته شده توسط %2$s",
    "Shares" : "موارد به اشتراک گذاشته",
    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
    "Password" : "گذرواژه",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Name" : "نام",
    "Share time" : "زمان به اشتراک گذاری",
    "Expiration date" : "تاریخ انقضا",
    "Sorry, this link doesn’t seem to work anymore." : "متاسفانه این پیوند دیگر کار نمی کند",
    "Reasons might be:" : "ممکن است به این دلایل باشد:",
    "the item was removed" : "این مورد حذف شده است",
    "the link expired" : "این پیوند منقضی شده است",
    "sharing is disabled" : "قابلیت اشتراک گذاری غیرفعال است",
    "For more info, please ask the person who sent this link." : "برای اطلاعات بیشتر، لطفا از شخصی که این پیوند را ارسال کرده سوال بفرمایید.",
    "%s is publicly shared" : "%s به اشتراک عمومی گذاشته شده است",
    "Add to your ownCloud" : "افزودن به ownCloud شما",
    "Download" : "دانلود",
    "Download %s" : "دانلود %s",
    "Direct link" : "پیوند مستقیم"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/fa.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "اشتراک سرور به سرور در این سرور فعال نیست .",
    "The mountpoint name contains invalid characters." : "نام نقطه ی اتصال حاوی کاراکتر های غیرمجاز است.",
    "Not allowed to create a federated share with the same user server" : "ایجاد اشتراک گذاری گروهی با کاربر سرور یکسان مجاز نمی باشد.",
    "Invalid or untrusted SSL certificate" : "گواهینامه SSL غیر قابل اعتماد یا غیر معتبر است.",
    "Could not authenticate to remote share, password might be wrong" : "احرازهویت برای اشتراک‌گذاری راه‌دور انجام نشد، احتمالا رمزعبور نادرست است",
    "Storage not valid" : "فضای ذخیره‌سازی معتبر نیست",
    "Couldn't add remote share" : "امکان افزودن اشتراک گذاری از راه دور وجود ندارد",
    "Shared with you" : "موارد به اشتراک گذاشته شده با شما",
    "Shared with others" : "موارد به اشتراک گذاشته شده با دیگران",
    "Shared by link" : "اشتراک گذاشته شده از طریق پیوند",
    "Uploading..." : "درحال بارگذاری...",
    "Nothing shared with you yet" : "هیچ موردی با شما به اشتراک گذاشته نشده است",
    "Files and folders others share with you will show up here" : "فایل ها و پوشه ها که دیگران با شما به اشتراک گذاشته اند در اینجا نمایش داده میشود.",
    "Nothing shared yet" : "هیچ موردی تاکنون به اشتراک گذاشته نشده است",
    "Files and folders you share will show up here" : "فایل ها و پوشه هایی که به اشتراک گذاشته اید در اینجا نمایش داده می شود.",
    "No shared links" : "هیچ لینک اشتراک‌گذاری وجود ندارد",
    "Files and folders you share by link will show up here" : "فایل‌ها و پوشه‌های اشتراک‌گذاشته توسط شما همراه با لینک در اینجا نمایش داده خواهد شد",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "آیا مایل به افزودن اشتراک از راه دور {name} از {owner}@{remote} هستید.",
    "Remote share" : "اشتراک از راه دور",
    "Remote share password" : "رمز عبور اشتراک از راه دور",
    "Cancel" : "منصرف شدن",
    "Add remote share" : "افزودن اشتراک از راه دور",
    "You can upload into this folder" : "می‌توانید در این پوشه آپلود کنید",
    "No ownCloud installation (7 or higher) found at {remote}" : "هیچ نصبinstallation (7 or higher) در  {remote} پیدا نشد.",
    "Invalid ownCloud url" : "آدرس نمونه ownCloud  غیر معتبر است",
    "Share" : "اشتراک گذاری",
    "No expiration date set" : "تاریخ انقضا تعیین نشده است.",
    "Shared by" : "اشتراک گذاشته شده به وسیله",
    "Sharing" : "اشتراک گذاری",
    "Share API is disabled" : "API اشتراک گذاری غیر فعال است.",
    "Wrong share ID, share doesn't exist" : "شناسه اشتراک گذاری اشتباه است، اشتراک گذاری وجود ندارد.",
    "Could not delete share" : "امکان حذف اشتراک گذاری وجود ندارد.",
    "Please specify a file or folder path" : "لطفا مسیر فایل یا پوشه را مشخص کنید.",
    "Wrong path, file/folder doesn't exist" : "مسیر اشتباه، فایل یا پوشه وجود ندارد.",
    "Please specify a valid user" : "لطفا یک کاربر معتبر را تعیین کنید.",
    "Group sharing is disabled by the administrator" : "اشتراک گذاری گروهی توسط مدیر غیر فعال شده است.",
    "Please specify a valid group" : "لطفا یک گروه معتبر را معرفی کنید.",
    "Public link sharing is disabled by the administrator" : "اشتراک گذاری لینک عمومی توسط مدیر غیر فعال شده است.",
    "Public upload disabled by the administrator" : "بارگذاری عمومی توسط مدیر غیر فعال شده است.",
    "Public upload is only possible for publicly shared folders" : "بارگذاری عمومی فقط برای پوشه های اشتراک گذاری عمومی امکان پذیر است.",
    "Invalid date, date format must be YYYY-MM-DD" : "تاریخ نامعتبر، قالب تاریخ باید YYYY-MM-DD باشد.",
    "Sharing %s failed because the back end does not allow shares from type %s" : "اشتراک گذاری %s ناموفق بود، زیرا اشتراک گذاری از نوع %s مجاز نیست.",
    "Unknown share type" : "نوع اشتراک گذاری نامعلوم.",
    "Not a directory" : "یک دایرکتوری نمی باشد.",
    "Could not lock path" : "امکان قفل کردن مسیر نمی باشد.",
    "Can't change permissions for public share links" : "امکان تغییر مجوز ها برای لینک های اشتراک گذاری عمومی فراهم نیست.",
    "Wrong or no update parameter given" : "پارامتر های بروز رسانی اشتباه اند یا تعیین نشده اند",
    "Cannot increase permissions" : "امکان افزایش مجوز ها نمی باشد",
    "A file or folder has been <strong>shared</strong>" : "فایل یا پوشه ای به <strong>اشتراک</strong> گذاشته شد",
    "A file or folder was shared from <strong>another server</strong>" : "یک فایل یا پوشه از <strong> سروری دیگر </strong>  به اشتراک گذاشته شد",
    "A public shared file or folder was <strong>downloaded</strong>" : "یک فایل یا پوشه به اشتراک گذاشته شده <strong> دانلود شده است</strong>",
    "You received a new remote share %2$s from %1$s" : "شما یک اشتراک گذاری ریموت %1$s از  %2$s دریافت کرده اید",
    "You received a new remote share from %s" : "شما یک اشتراک گذاری جدید دریافت کرده اید از%s",
    "%1$s accepted remote share %2$s" : "%1$s پذیرفته یک اشتراک گذاری ریموت را%2$s",
    "%1$s declined remote share %2$s" : "%1$s اشتراک گذاری ریموت %2$s را معتبر نمیداند",
    "%1$s unshared %2$s from you" : "%1$s از اشتراک گذاری %2$s با شما خارج شد",
    "Public shared folder %1$s was downloaded" : "پوشه ی اشتراک گذاری عمومی  %1$s دانلود شده است",
    "Public shared file %1$s was downloaded" : "فایل اشتراک گذاری عمومی  %1$s دانلود شده است",
    "You shared %1$s with %2$s" : "شما %1$s را با %2$s به اشتراک گذاشتید",
    "%2$s shared %1$s with %3$s" : "%2$s به اشتراک گذاشته شد %1$s با %3$s",
    "You removed the share of %2$s for %1$s" : "شما اشتراک گذاری %2$s برای %1$s را حذف کرده اید",
    "%2$s removed the share of %3$s for %1$s" : "%2$s اشتراک گذاری %3$s برای %1$s حذف شده است",
    "You shared %1$s with group %2$s" : "شما %1$s را با گروه %2$s به اشتراک گذاشتید",
    "%2$s shared %1$s with group %3$s" : "%2$s به اشتراک گذاشته شد  %1$s با گروه %3$s",
    "You removed the share of group %2$s for %1$s" : "شما اشتراک گذاری گروه %2$s برای %1$s را حذف کرده اید",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s اشتراک گذاری گروه %3$s برای %1$s حذف شده است",
    "%2$s shared %1$s via link" : "%2$s به اشتراک گذاشته شده %1$s از طریق لینک",
    "You shared %1$s via link" : "شما %1$s را توسط پیوند به اشتراک گذاشتید",
    "You removed the public link for %1$s" : "شما لینک عمومی برای %1$s را حذف کرده اید",
    "%2$s removed the public link for %1$s" : "%2$s لینک عمومی برای %1$s حذف شده است",
    "Your public link for %1$s expired" : "لینک عمومی شما برای %1$s منقضی شده است",
    "The public link of %2$s for %1$s expired" : "لینک عمومی %2$s برای %1$s منقضی شده است",
    "%2$s shared %1$s with you" : "%2$s مورد %1$s را با شما به اشتراک گذاشت",
    "%2$s removed the share for %1$s" : "%2$s اشتراک گذاری برای%1$s را حذف کرده است ",
    "Downloaded via public link" : "دانلود از طریق لینک عمومی",
    "Shared with %2$s" : "اشتراک گذاشته شده با %2$s",
    "Shared with %3$s by %2$s" : "اشتراک گذاشته شده با %3$s توسط%2$s ",
    "Removed share for %2$s" : "اشتراک گذاری %2$s حذف شده است",
    "%2$s removed share for %3$s" : "%2$sاشتراک گذاری برای %3$s را حذف کرده است ",
    "Shared with group %2$s" : "اشتراک گذاشته شده با گروه %2$s",
    "Shared with group %3$s by %2$s" : "به اشتراک گذاشته شده با گروه %3$s توسط %2$s",
    "Removed share of group %2$s" : "حذف شده از اشتراک گذاری گروه %2$s",
    "%2$s removed share of group %3$s" : "%2$s از گروه %3$s حذف شده است",
    "Shared via link by %2$s" : "به اشتراک گذاشته شده با لینک توسط %2$s",
    "Shared via public link" : "به اشتراک گذاشته شده از طریق لینک عمومی",
    "Removed public link" : "لینک عمومی حذف شده است",
    "%2$s removed public link" : "%2$s لینک  عمومی را حذف کرده است",
    "Public link expired" : "لینک عمومی منقضی شده است",
    "Public link of %2$s expired" : "لینک عمومی %2$s منقضی شده است",
    "Shared by %2$s" : "به اشتراک گذاشته شده توسط %2$s",
    "Shares" : "موارد به اشتراک گذاشته",
    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
    "Password" : "گذرواژه",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Name" : "نام",
    "Share time" : "زمان به اشتراک گذاری",
    "Expiration date" : "تاریخ انقضا",
    "Sorry, this link doesn’t seem to work anymore." : "متاسفانه این پیوند دیگر کار نمی کند",
    "Reasons might be:" : "ممکن است به این دلایل باشد:",
    "the item was removed" : "این مورد حذف شده است",
    "the link expired" : "این پیوند منقضی شده است",
    "sharing is disabled" : "قابلیت اشتراک گذاری غیرفعال است",
    "For more info, please ask the person who sent this link." : "برای اطلاعات بیشتر، لطفا از شخصی که این پیوند را ارسال کرده سوال بفرمایید.",
    "%s is publicly shared" : "%s به اشتراک عمومی گذاشته شده است",
    "Add to your ownCloud" : "افزودن به ownCloud شما",
    "Download" : "دانلود",
    "Download %s" : "دانلود %s",
    "Direct link" : "پیوند مستقیم",
    "Pending" : "در انتظار",
    "Accept" : "قبول"
},
"nplurals=1; plural=0;");
